@@ -74,11 +74,11 @@ class BlockTimestampGraph(object):
 
     def get_first_point(self):
         # Ignore the genesis block as its timestamp is 0
-        return get_point(1)
+        return self.get_point(1)
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
-        return get_point(6779286) #TODO: query status to get latest
+        return self.get_point(6779286) #TODO: query status to get latest
 
     def get_point(self, x):
 #        return block_to_point(self._theta_provider.eth.getBlock(x))
